@@ -47,7 +47,7 @@ navbarPage(title = HTML('<h3><strong><a target="_blank" href="https://inkaverse.
                     , includeCSS("www/custom.css")
                     , tags$head(includeHTML(("www/analytics.html")))
                     , tags$head(tags$link(rel="shortcut icon"
-                                          , href="https://flavjack.github.io/inti/logo.png")),
+                                          , href="https://flavjack.github.io/inti/img/inkaverse.png")),
                     
                     meta() %>%
                       meta_social(
